import React from "react"
import ThemeContext from "../../context/ThemeContext"
import { Menu, Dropdown, Button } from "antd"
import { DownOutlined } from "@ant-design/icons"
import JsonLanguages from "../../settings/languages.json"

const LangSwitcher = () => {
	return (
		<ThemeContext.Consumer>
			{({ currentLang, toggleLanguage }) => {
				const validLangs = JsonLanguages.filter((l) => l.enabled)
				if (!validLangs || validLangs.length < 2) {
					return null
				}

				return (
					<Dropdown
						overlay={
							<Menu>
								{JsonLanguages.map((lang) => {
									return (
										lang.enabled && (
											<Menu.Item key={lang.path}>
												<a
													href={`#${lang.key}`}
													onClick={(e) => {
														e.preventDefault()
														toggleLanguage(lang.key, lang.locale, lang.message)
													}}
												>
													{lang.title}
												</a>
											</Menu.Item>
										)
									)
								})}
							</Menu>
						}
					>
						<Button
							type="link"
							className="langLinkWrapper"
							onClick={(e) => e.preventDefault()}
						>
							{JsonLanguages
								? JsonLanguages.filter((item) => item.key === currentLang)[0]
										.title
								: `No language!`}
							<DownOutlined />
						</Button>
					</Dropdown>
				)
			}}
		</ThemeContext.Consumer>
	)
}

export default LangSwitcher
