import React, { useContext, useState, useEffect, useRef } from "react"
import { Table, Input, Button, Popconfirm, Form, Select, Space } from "antd"
import { PlusOutlined } from "@ant-design/icons"

const { Option } = Select

const EditableContext = React.createContext(null)
const EditableContextAdd = React.createContext(null)

const EditableRow = ({ index, ...props }) => {
	const [form] = Form.useForm()
	return (
		<Form form={form} component={false}>
			<EditableContext.Provider value={form}>
				<tr {...props} />
			</EditableContext.Provider>
		</Form>
	)
}
const EditableRowAdd = ({ index, ...props }) => {
	const [formAdd] = Form.useForm()

	return (
		<Form form={formAdd} component={false}>
			<EditableContextAdd.Provider value={formAdd}>
				<tr {...props} />
			</EditableContextAdd.Provider>
		</Form>
	)
}

const EditableCell = ({
	title,
	editable,
	children,
	inputType,
	dataIndex,
	record,
	handleSave,
	...restProps
}) => {
	const [editing, setEditing] = useState(false)
	const inputRef = useRef(null)
	const form = useContext(EditableContext)
	useEffect(() => {
		if (editing) {
			inputRef.current.focus()
		}
	}, [editing])

	const toggleEdit = () => {
		setEditing(!editing)
		form.setFieldsValue({
			[dataIndex]: record[dataIndex],
		})
	}

	const save = async () => {
		try {
			const values = await form.validateFields()
			toggleEdit()
			handleSave({ ...record, ...values })
		} catch (errInfo) {
			console.log("Save failed:", errInfo)
		}
	}

	let childNode = children

	if (editable) {
		childNode = editing ? (
			<Form.Item
				style={{
					margin: 0,
				}}
				name={dataIndex}
				rules={[
					{
						required: true,
						message: `${title} is required.`,
					},
				]}
			>
				{inputType === "select" ? (
					<Select ref={inputRef} onChange={save} onBlur={save}>
						<Option value="Internal">Internal</Option>
						<Option value="External">External</Option>
					</Select>
				) : (
					<Input ref={inputRef} onPressEnter={save} onBlur={save} />
				)}
			</Form.Item>
		) : (
			<div
				className="editable-cell-value-wrap"
				style={{
					paddingRight: 24,
				}}
				onClick={toggleEdit}
			>
				{children}
			</div>
		)
	}

	return <td {...restProps}>{childNode}</td>
}

/*const EditableCellAdd = ({
	title,
	editable,
	children,
	inputType,
	dataIndex,
	record,
	handleSaveAdd,
	...restProps
}) => {
	const [editingAdd, setEditingAdd] = useState(false)
	const inputRefAdd = useRef(null)
	const formAdd = useContext(EditableContextAdd)
	useEffect(() => {
		if (editingAdd) {
			inputRefAdd.current.focus()
		}
	}, [editingAdd])

	const toggleEditAdd = () => {
		setEditingAdd(!editingAdd)
		formAdd.setFieldsValue({
			[dataIndex]: record[dataIndex],
		})
	}

	const saveAdd = async () => {
		try {
			const values = await formAdd.validateFields()
			toggleEditAdd()
			handleSaveAdd({ ...record, ...values })
		} catch (errInfo) {
			console.log("Save add failed:", errInfo)
		}
	}

	let childNode = children

	if (editable) {
		childNode = editingAdd ? (
			<Form.Item
				style={{
					margin: 0,
				}}
				name={dataIndex}
				rules={[
					{
						required: true,
						message: `${title} is required.`,
					},
				]}
			>
				{(() => {
					if (dataIndex === "link") {
						return (
							<Select ref={inputRefAdd} onChange={saveAdd} onBlur={saveAdd}>
								<Option value="Internal">Internal</Option>
								<Option value="External">External</Option>
							</Select>
						)
					} else {
						return (
							<Input
								ref={inputRefAdd}
								onPressEnter={saveAdd}
								onBlur={saveAdd}
							/>
						)
					}
				})()}
			</Form.Item>
		) : (
			<div
				className="editable-cell-value-wrap"
				style={{
					paddingRight: 24,
				}}
				onClick={toggleEditAdd}
			>
				{children}
			</div>
		)
	}

	return <td {...restProps}>{childNode}</td>
}*/

class EditableTableMenus extends React.Component {
	constructor(props) {
		super(props)
		this.columns = [
			{
				title: "Slug",
				dataIndex: "slug",
				editable: true,
			},
			{
				title: "Title",
				dataIndex: "title",
				editable: true,
			},
			{
				title: "Path",
				dataIndex: "path",
				editable: true,
			},
			{
				title: "Link",
				dataIndex: "link",
				editable: true,
				render: (_, record) => {
					return (
						<Select defaultValue={record.link}>
							<Option value="Internal">Internal</Option>
							<Option value="External">External</Option>
						</Select>
					)
				},
			},
			{
				title: "Operation",
				dataIndex: "operation",
				align: "right",
				fixed: "right",
				render: (_, record, rowIndex) => {
					return (
						<Space size="middle">
							<Popconfirm
								title="Sure to add?"
								onConfirm={() => this.handleAddMenu(record, rowIndex)}
							>
								<a>Add</a>
							</Popconfirm>
							<Popconfirm
								title="Sure to delete?"
								onConfirm={() => this.handleDeleteMenu(record)}
							>
								<a>Delete</a>
							</Popconfirm>
						</Space>
					)
				},
			},
		]
		/*this.columnsAdd = [
			{
				title: "Key",
				dataIndex: "key",
				editable: true,
			},
			{
				title: "Title",
				dataIndex: "title",
				editable: true,
			},
			{
				title: "Path",
				dataIndex: "path",
				editable: true,
			},
			{
				title: "Link",
				dataIndex: "link",
				editable: true,
				render: (_, record) => {
					return (
						<Select defaultValue={record.link}>
							<Option value="Internal">Internal</Option>
							<Option value="External">External</Option>
						</Select>
					)
				},
			},
			{
				title: "Child",
				dataIndex: "child",
				editable: true,
			},
			{
				title: "Operation",
				dataIndex: "operation",
				align: "right",
				fixed: "right",
				render: (_, record) => {
					return (
						<Button
							onClick={this.handleAdd}
							type="dashed"
							icon={<PlusOutlined />}
						>
							Add
						</Button>
					)
				},
			},
		]*/

		this.state = {
			dataSource: [
				{
					key: 0,
					slug: "home",
					title: "Home",
					path: "/",
					link: "Internal",
					child: "false",
				},
				{
					key: 1,
					slug: "deeboon",
					title: "Deeboon",
					path: "https://www.deeboon.co.th/",
					link: "External",
					child: "false",
				},
				{
					key: 2,
					slug: "post",
					title: "Post",
					path: "/post",
					link: "Internal",
					child: "false",
					children: [
						{
							key: 3,
							slug: "post-1",
							title: "blog test",
							path: "/blog-1",
							link: "Internal",
							child: "true",
						},
						{
							key: 4,
							slug: "post-2",
							title: "blog two",
							path: "/blog-2",
							link: "External",
							child: "true",
						},
					],
				},
			],
			count: 5,
			dataSourceAdd: [
				{
					key: "new",
					title: "New",
					path: "/new",
					link: "Internal",
					child: "false",
				},
			],
		}
	}

	handleDeleteMenu = (row) => {
		if (row) {
			const { dataSource } = this.state
			if (row.child === "true") {
				const removeData = dataSource.map((root, i) => {
					const children = root.children
					if (children && children.length > 0) {
						for (var j = 0; j < children.length; j++) {
							if (children[j].key === row.key) {
								children.splice(j, 1)
							}
						}
					}
					return root
				})
				this.setState({
					dataSource: removeData,
				})
			} else {
				this.setState({
					dataSource: dataSource.filter((item) => item.key !== row.key),
				})
			}
		}
	}

	/*handleAdd = () => {
		const { count, dataSource, dataSourceAdd } = this.state
		//console.log("dataSourceAdd ", dataSourceAdd)
		if (dataSourceAdd && dataSourceAdd.length > 0) {
			const isChild = dataSourceAdd[0].child
			if (isChild === "false") {
				//dataSource.splice(dataSource.length, 0, dataSourceAdd)
				this.setState({
					dataSource: [...dataSource, dataSourceAdd[0]],
					count: count + 1,
				})
			} else {
				const addKey = dataSourceAdd[0].key
				this.state.dataSource.map((root, i) => {
					if (root.key === addKey) {
						dataSource.splice()
					} else {
						const children = root.children
						if (children && children.length > 0) {
							children.map((child, j) => {
								if (child.key === addKey) {
								}
							})
						}	
					}
				})
			}
		}
	}*/

	handleAddMenu = (row, index) => {
		const newData = [...this.state.dataSource]
		if (row) {
			const isChild = row.child
			if (isChild === "true") {
				const addData = this.state.dataSource.map((root) => {
					let children = root.children
					if (children && children.length > 0) {
						for (var j = 0; j < children.length; j++) {
							if (children[j].key === row.key) {
								const menuData = {
									key: Date.now(),
									slug: "new-child",
									title: "New child",
									path: "/new-child",
									link: "Internal",
									child: "true",
								}
								children.splice(j, 0, menuData)
								break
							}
						}
					}
					return root
				})
				this.setState({
					dataSource: addData,
				})
			} else {
				this.state.dataSource.map((root) => {
					if (root.key === row.key) {
						const menuData = {
							key: Date.now(),
							slug: "new",
							title: "New",
							path: "/new",
							link: "Internal",
							child: "false",
						}
						newData.splice(index, 0, menuData)
					}
				})
				this.setState({
					dataSource: newData,
				})
			}
		}
	}

	handleSave = (row) => {
		const newData = [...this.state.dataSource]
		if (row.child === "false") {
			this.state.dataSource.map((root, i) => {
				if (root.key === row.key) {
					newData.splice(i, 1, row)
				}
			})
			this.setState({
				dataSource: newData,
			})
		} else {
			this.state.dataSource.map((root, i) => {
				const children = root.children
				if (children && children.length > 0) {
					children.map((child, j) => {
						if (child.key === row.key) {
							root.children[j] = row
							newData.splice(i, 1, root)
						}
					})
				}
			})
			this.setState({
				dataSource: newData,
			})
		}
	}

	/*handleSaveAdd = (row) => {
		const newData = [...this.state.dataSourceAdd]
		newData.splice(0, 1, row)
		this.setState({
			dataSourceAdd: newData,
		})
	}*/

	handleProcess = () => {
		const { dataSource } = this.state
		console.log("dataSource ", dataSource)
	}

	render() {
		const { dataSource, dataSourceAdd } = this.state
		//console.log("dataSource render ", dataSource)
		const components = {
			body: {
				row: EditableRow,
				cell: EditableCell,
			},
		}
		/*const componentsAdd = {
			body: {
				row: EditableRowAdd,
				cell: EditableCellAdd,
			},
		}*/
		const columns = this.columns.map((col) => {
			if (!col.editable) {
				return col
			}

			return {
				...col,
				onCell: (record) => ({
					record,
					editable: col.editable,
					inputType: col.dataIndex === "link" ? "select" : "text",
					dataIndex: col.dataIndex,
					title: col.title,
					handleSave: this.handleSave,
				}),
			}
		})

		/*const columnsAdd = this.columnsAdd.map((col) => {
			if (!col.editable) {
				return col
			}

			return {
				...col,
				onCell: (record) => ({
					record,
					editable: col.editable,
					inputType: col.dataIndex === "link" ? "select" : "text",
					dataIndex: col.dataIndex,
					title: col.title,
					handleSaveAdd: this.handleSaveAdd,
				}),
			}
		})*/

		return (
			<div className="editableMenusContainer">
				<div className="topWrapper">
					<p>Primary menu</p>
					<Button onClick={this.handleProcess} type="primary">
						Save
					</Button>
				</div>
				<Table
					rowKey="key"
					components={components}
					rowClassName={() => "editable-row"}
					dataSource={dataSource}
					columns={columns}
					pagination={false}
				/>
				<div className="bottomWrapper">
					<div className="formWrapper">
						{/* <Table
							components={componentsAdd}
							rowClassName={() => "editable-row"}
							dataSource={dataSourceAdd}
							columns={columnsAdd}
							pagination={false}
						/> */}
					</div>
					{/* <Button
						onClick={this.handleAdd}
						type="dashed"
						icon={<PlusOutlined />}
					>
						Add menu
					</Button> */}
				</div>
			</div>
		)
	}
}

export default EditableTableMenus
