import React, { useState, useEffect } from "react"
import { isAdministrator } from "../../../services/auth"
import { navigate } from "gatsby"
import ProTable, { ProColumns } from "@ant-design/pro-table"
import { notification, Switch } from "antd"
import JsonLanguages from "../../../settings/languages.json"

const columns: ProColumns[] = [
	{
		title: "#",
		dataIndex: "index",
		valueType: "indexBorder",
		width: 48,
		key: "key",
	},
	{
		title: "Title",
		dataIndex: "title",
	},
	{
		title: "Path",
		dataIndex: "path",
	},
	{
		title: "Enabled",
		dataIndex: "enabled",
		align: "right",
		render: (_, record) => (
			<Switch defaultChecked={record.enabled} size="small" />
		),
	},
	{
		title: "Default",
		dataIndex: "default",
		align: "right",
		render: (_, record) => (
			<Switch defaultChecked={record.default} size="small" />
		),
	},
]

const Languages = () => {
	const [dataSource, {}] = useState(JsonLanguages)

	useEffect(() => {
		if (!isAdministrator()) {
			notification["warning"]({
				message: "Warning!",
				description: "Your account is not allowed!",
			})
			navigate("/backend/dashboard")
		}
	}, [])

	return (
		<ProTable
			columns={columns}
			request={(params, sorter, filter) => {
				return Promise.resolve({
					data: dataSource,
					success: true,
				})
			}}
			rowKey="key"
			options={false}
			search={false}
			pagination={false}
		/>
	)
}

export default Languages
