import React from "react"
import JsonLanguages from "../settings/languages.json"

const defaultState = {
	currentLang: `enUS`,
	currentLocale: `en-US`,
	currentMessage: `enMessages`,
	toggleLanguage: (lang, locale, message) => {},
}
const ThemeContext = React.createContext(defaultState)

class ThemeProvider extends React.Component {
	constructor(props) {
		super(props)

		const validLangs = JsonLanguages.filter((l) => l.enabled)
		if (!validLangs || validLangs.length < 2) {
			if (validLangs) {
				const { key, locale, message } = validLangs[0]
				this.state = {
					currentLang: key,
					currentLocale: locale,
					currentMessage: message,
				}
			}
		} else {
			this.state = {
				currentLang: `enUS`,
				currentLocale: `en-US`,
				currentMessage: `enMessages`,
			}
		}
	}

	toggleLanguage = (lang, locale, message) => {
		this.setState({
			currentLang: lang,
			currentLocale: locale,
			currentMessage: message,
		})
	}

	render() {
		const { children } = this.props
		const { currentLang, currentLocale, currentMessage } = this.state

		return (
			<ThemeContext.Provider
				value={{
					currentLang,
					currentLocale,
					currentMessage,
					toggleLanguage: this.toggleLanguage,
				}}
			>
				{children}
			</ThemeContext.Provider>
		)
	}
}

export default ThemeContext

export { ThemeProvider }
