import React, { useState } from "react"
import { FormattedMessage } from "react-intl"
import { navigate } from "gatsby"
import { fetchLogin, fetchSignUp } from "../../services/auth"
import Layout from "../../components/Layout"
import { Tabs, Form, Input, Checkbox, Button } from "antd"
import "./signin.less"

const { TabPane } = Tabs
const formLayout = {
	labelCol: {
		span: 6,
	},
	wrapperCol: {
		span: 14,
	},
}
const tailLayout = {
	wrapperCol: {
		offset: 6,
		span: 14,
	},
}

const Signin = () => {
	const [submitLogin, setSubmitLogin] = useState(false)
	const [submitSignup, setSubmitSignup] = useState(false)

	const onFinishLogin = async (values) => {
		setSubmitLogin(true)
		const status = await fetchLogin(
			values.email_login,
			values.password_login,
			values.remember_login
		)
		if (status === false) {
			setSubmitLogin(false)
		} else {
			navigate("/backend/dashboard")
		}
	}
	const onFinishSignup = async (values) => {
		setSubmitSignup(true)
		const status = await fetchSignUp(
			values.email_signup,
			values.password_signup
		)
		if (status === false) {
			setSubmitSignup(false)
		} else {
			navigate("/backend/dashboard")
		}
	}

	return (
		<Layout>
			<div className="pageContainer">
				<Tabs defaultActiveKey="1" centered>
					<TabPane tab={<FormattedMessage id="auth.login" />} key="1">
						<Form
							{...formLayout}
							onFinish={onFinishLogin}
							className="customForm"
						>
							<Form.Item
								label={<FormattedMessage id="auth.email" />}
								name="email_login"
								rules={[
									{
										required: true,
										message: (
											<FormattedMessage id="auth.message.email.required" />
										),
									},
									{
										type: "email",
										message: <FormattedMessage id="auth.message.email.type" />,
									},
								]}
							>
								<Input />
							</Form.Item>
							<Form.Item
								label={<FormattedMessage id="auth.password" />}
								name="password_login"
								rules={[
									{
										required: true,
										message: (
											<FormattedMessage id="auth.message.password.required" />
										),
									},
								]}
							>
								<Input.Password />
							</Form.Item>
							<Form.Item
								{...tailLayout}
								name="remember_login"
								valuePropName="checked"
							>
								<Checkbox>
									<FormattedMessage id="auth.remember" />
								</Checkbox>
							</Form.Item>
							<Form.Item {...tailLayout}>
								<Button
									type="primary"
									htmlType="submit"
									disabled={submitLogin}
									loading={submitLogin}
								>
									<FormattedMessage id="auth.login" />
								</Button>
							</Form.Item>
						</Form>
					</TabPane>
					<TabPane tab={<FormattedMessage id="auth.signup" />} key="2">
						<Form
							{...formLayout}
							onFinish={onFinishSignup}
							className="customForm"
						>
							<Form.Item
								label={<FormattedMessage id="auth.email" />}
								name="email_signup"
								rules={[
									{
										required: true,
										message: (
											<FormattedMessage id="auth.message.email.required" />
										),
									},
									{
										type: "email",
										message: <FormattedMessage id="auth.message.email.type" />,
									},
								]}
							>
								<Input />
							</Form.Item>
							<Form.Item
								label={<FormattedMessage id="auth.password" />}
								name="password_signup"
								rules={[
									{
										required: true,
										message: (
											<FormattedMessage id="auth.message.password.required" />
										),
									},
								]}
							>
								<Input.Password />
							</Form.Item>
							<Form.Item {...tailLayout}>
								<Button
									type="primary"
									htmlType="submit"
									disabled={submitSignup}
									loading={submitSignup}
								>
									<FormattedMessage id="auth.signup" />
								</Button>
							</Form.Item>
						</Form>
					</TabPane>
				</Tabs>
			</div>
		</Layout>
	)
}

export default Signin
