import GoTrue from "gotrue-js"
import { navigate } from "gatsby"
import { notification } from "antd"

const gotrue = new GoTrue({
	APIUrl: `https://${process.env.GATSBY_NETLIFY_SITE_DOMAIN}/.netlify/identity`,
	audience: "",
	setCookie: true,
})

export const isAuthenticated = () => {
	const user = gotrue.currentUser()
	if (user && user.email) {
		return true
	}

	return false
}
export const login = () => {
	const user = gotrue.currentUser()
	if (user && user.email) {
		navigate("/backend/dashboard")
	} else {
		navigate("/auth/signin")
	}
}
export const getProfile = () => {
	const user = gotrue.currentUser()
	return user
}
export const isAdministrator = () => {
	const user = gotrue.currentUser()
	if (
		user.app_metadata.roles &&
		user.app_metadata.roles.indexOf("Administrator") > -1
	) {
		return true
	}

	return false
}
export const logout = () => {
	const user = gotrue.currentUser()
	user
		.logout()
		.then(() => {
			navigate("/")
		})
		.catch((error) => {
			console.log("Failed to logout user: %o", error)
			throw error
		})
}

export const fetchLogin = (email, password, remember) => {
	const cango = gotrue
		.login(email, password, remember)
		.then(() => {
			return true
		})
		.catch((error) => {
			notification["error"]({
				message: error.name + " code " + error.status,
				description: error.json.error_description,
				duration: 0,
			})
			return false
		})
	return cango
}

export const fetchSignUp = (email, password) => {
	const cango = gotrue
		.signup(email, password)
		.then(() => {
			fetchLogin(email, password, true)
			return true
		})
		.catch((error) => {
			notification["error"]({
				message: error.name + " code " + error.status,
				description: error.json.msg,
				duration: 0,
			})
			return false
		})
	return cango
}
